==> icedtea-bin-src-3.0.0_pre08.tar.xz: com/sun/swing/internal/plaf/basic/resources/basic_ko.java <==
package com.sun.swing.internal.plaf.basic.resources;

import java.util.ListResourceBundle;

public final class basic_ko extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "AbstractButton.click.textAndMnemonic", "\uB204\uB974\uAE30" },
            { "AbstractDocument.addition.textAndMnemonic", "\uCD94\uAC00" },
            { "AbstractDocument.deletion.textAndMnemonic", "\uC0AD\uC81C" },
            { "AbstractDocument.redo.textAndMnemonic", "\uC7AC\uC2E4\uD589" },
            { "AbstractDocument.styleChange.textAndMnemonic", "\uC2A4\uD0C0\uC77C \uBCC0\uACBD" },
            { "AbstractDocument.undo.textAndMnemonic", "\uC2E4\uD589 \uCDE8\uC18C" },
            { "AbstractUndoableEdit.redo.textAndMnemonic", "\uC7AC\uC2E4\uD589" },
            { "AbstractUndoableEdit.undo.textAndMnemonic", "\uC2E4\uD589 \uCDE8\uC18C" },
            { "ColorChooser.cancel.textAndMnemonic", "\uCDE8\uC18C" },
            { "ColorChooser.cmyk.textAndMnemonic", "C&MYK" },
            { "ColorChooser.cmykAlpha.textAndMnemonic", "\uC54C\uD30C" },
            { "ColorChooser.cmykBlack.textAndMnemonic", "\uAC80\uC815\uC0C9" },
            { "ColorChooser.cmykCyan.textAndMnemonic", "\uCCAD\uB85D\uC0C9" },
            { "ColorChooser.cmykMagenta.textAndMnemonic", "\uC9C4\uD64D\uC0C9" },
            { "ColorChooser.cmykYellow.textAndMnemonic", "\uB178\uB780\uC0C9" },
            { "ColorChooser.hsl.textAndMnemonic", "HSL(&L)" },
            { "ColorChooser.hslHue.textAndMnemonic", "\uC0C9\uC870" },
            { "ColorChooser.hslLightness.textAndMnemonic", "\uBC1D\uAE30" },
            { "ColorChooser.hslSaturation.textAndMnemonic", "\uCC44\uB3C4" },
            { "ColorChooser.hslTransparency.textAndMnemonic", "\uD22C\uBA85" },
            { "ColorChooser.hsv.textAndMnemonic", "HSV(&H)" },
            { "ColorChooser.hsvHue.textAndMnemonic", "\uC0C9\uC870" },
            { "ColorChooser.hsvSaturation.textAndMnemonic", "\uCC44\uB3C4" },
            { "ColorChooser.hsvTransparency.textAndMnemonic", "\uD22C\uBA85" },
            { "ColorChooser.hsvValue.textAndMnemonic", "\uAC12" },
            { "ColorChooser.ok.textAndMnemonic", "\uD655\uC778" },
            { "ColorChooser.preview.textAndMnemonic", "\uBBF8\uB9AC\uBCF4\uAE30" },
            { "ColorChooser.reset.textAndMnemonic", "\uC7AC\uC124\uC815(&R)" },
            { "ColorChooser.rgb.textAndMnemonic", "RGB(&G)" },
            { "ColorChooser.rgbAlpha.textAndMnemonic", "\uC54C\uD30C" },
            { "ColorChooser.rgbBlue.textAndMnemonic", "\uD30C\uB780\uC0C9(&B)" },
            { "ColorChooser.rgbGreen.textAndMnemonic", "\uB179\uC0C9(&N)" },
            { "ColorChooser.rgbHexCode.textAndMnemonic", "\uC0C9\uC0C1 \uCF54\uB4DC(&C)" },
            { "ColorChooser.rgbRed.textAndMnemonic", "\uBE68\uAC04\uC0C9(&D)" },
            { "ColorChooser.sample.textAndMnemonic", "\uC0D8\uD50C \uD14D\uC2A4\uD2B8  \uC0D8\uD50C \uD14D\uC2A4\uD2B8" },
            { "ColorChooser.swatches.textAndMnemonic", "\uACAC\uBCF8(&S)" },
            { "ColorChooser.swatchesRecent.textAndMnemonic", "\uCD5C\uADFC \uBAA9\uB85D:" },
            { "ComboBox.togglePopup.textAndMnemonic", "togglePopup" },
            { "FileChooser.acceptAllFileFilter.textAndMnemonic", "\uBAA8\uB4E0 \uD30C\uC77C" },
            { "FileChooser.cancelButton.textAndMnemonic", "\uCDE8\uC18C" },
            { "FileChooser.cancelButtonToolTip.textAndMnemonic", "\uD30C\uC77C \uC120\uD0DD\uAE30 \uB300\uD654\uC0C1\uC790 \uC911\uB2E8" },
            { "FileChooser.directoryDescription.textAndMnemonic", "\uB514\uB809\uD1A0\uB9AC" },
            { "FileChooser.directoryOpenButton.textAndMnemonic", "\uC5F4\uAE30" },
            { "FileChooser.directoryOpenButtonToolTip.textAndMnemonic", "\uC120\uD0DD\uB41C \uB514\uB809\uD1A0\uB9AC \uC5F4\uAE30" },
            { "FileChooser.fileDescription.textAndMnemonic", "\uC77C\uBC18 \uD30C\uC77C" },
            { "FileChooser.fileSizeGigaBytes", "{0} GB" },
            { "FileChooser.fileSizeKiloBytes", "{0} KB" },
            { "FileChooser.fileSizeMegaBytes", "{0} MB" },
            { "FileChooser.filesDetailsAccessibleName", "\uD30C\uC77C \uC138\uBD80 \uC815\uBCF4" },
            { "FileChooser.filesListAccessibleName", "\uD30C\uC77C \uBAA9\uB85D" },
            { "FileChooser.helpButton.textAndMnemonic", "\uB3C4\uC6C0\uB9D0(&H)" },
            { "FileChooser.helpButtonToolTip.textAndMnemonic", "FileChooser \uB3C4\uC6C0\uB9D0" },
            { "FileChooser.newFolderError.textAndMnemonic", "\uC0C8 \uD3F4\uB354\uB97C \uC0DD\uC131\uD558\uB294 \uC911 \uC624\uB958\uAC00 \uBC1C\uC0DD\uD588\uC2B5\uB2C8\uB2E4." },
            { "FileChooser.newFolderErrorSeparator", ":" },
            { "FileChooser.newFolderParentDoesntExist.textAndMnemonic", "\uD3F4\uB354\uB97C \uC0DD\uC131\uD560 \uC218 \uC5C6\uC2B5\uB2C8\uB2E4.\n\n\uC2DC\uC2A4\uD15C\uC5D0\uC11C \uC9C0\uC815\uB41C \uACBD\uB85C\uB97C \uCC3E\uC744 \uC218 \uC5C6\uC2B5\uB2C8\uB2E4." },
            { "FileChooser.newFolderParentDoesntExistTitle.textAndMnemonic", "\uD3F4\uB354\uB97C \uC0DD\uC131\uD560 \uC218 \uC5C6\uC74C" },
            { "FileChooser.openButton.textAndMnemonic", "\uC5F4\uAE30" },
            { "FileChooser.openButtonToolTip.textAndMnemonic", "\uC120\uD0DD\uB41C \uD30C\uC77C \uC5F4\uAE30" },
            { "FileChooser.openDialogTitle.textAndMnemonic", "\uC5F4\uAE30" },
            { "FileChooser.other.newFolder", "NewFolder" },
            { "FileChooser.other.newFolder.subsequent", "NewFolder.{0}" },
            { "FileChooser.renameError.textAndMnemonic", "{0}\uC758 \uC774\uB984\uC744 \uBC14\uAFC0 \uC218 \uC5C6\uC2B5\uB2C8\uB2E4." },
            { "FileChooser.renameErrorFileExists.textAndMnemonic", "{0}\uC758 \uC774\uB984\uC744 \uBC14\uAFC0 \uC218 \uC5C6\uC74C: \uC9C0\uC815\uD55C \uC774\uB984\uC744 \uC0AC\uC6A9\uD558\uB294 \uD30C\uC77C\uC774 \uC874\uC7AC\uD569\uB2C8\uB2E4. \uB2E4\uB978 \uD30C\uC77C \uC774\uB984\uC744 \uC9C0\uC815\uD558\uC2ED\uC2DC\uC624." },
            { "FileChooser.renameErrorTitle.textAndMnemonic", "\uD30C\uC77C \uB610\uB294 \uD3F4\uB354 \uC774\uB984 \uBC14\uAFB8\uB294 \uC911 \uC624\uB958 \uBC1C\uC0DD" },
            { "FileChooser.saveButton.textAndMnemonic", "\uC800\uC7A5" },
            { "FileChooser.saveButtonToolTip.textAndMnemonic", "\uC120\uD0DD\uB41C \uD30C\uC77C \uC800\uC7A5" },
            { "FileChooser.saveDialogTitle.textAndMnemonic", "\uC800\uC7A5" },
            { "FileChooser.updateButton.textAndMnemonic", "\uC5C5\uB370\uC774\uD2B8(&U)" },
            { "FileChooser.updateButtonToolTip.textAndMnemonic", "\uB514\uB809\uD1A0\uB9AC \uBAA9\uB85D \uC5C5\uB370\uC774\uD2B8" },
            { "FileChooser.win32.newFolder", "\uC0C8 \uD3F4\uB354" },
            { "FileChooser.win32.newFolder.subsequent", "\uC0C8 \uD3F4\uB354({0})" },
            { "FormView.browseFileButton.textAndMnemonic", "\uCC3E\uC544\uBCF4\uAE30..." },
            { "FormView.resetButton.textAndMnemonic", "\uC7AC\uC124\uC815" },
            { "FormView.submitButton.textAndMnemonic", "\uC9C8\uC758 \uC81C\uCD9C" },
            { "InternalFrame.closeButtonToolTip", "\uB2EB\uAE30" },
            { "InternalFrame.iconButtonToolTip", "\uCD5C\uC18C\uD654" },
            { "InternalFrame.maxButtonToolTip", "\uCD5C\uB300\uD654" },
            { "InternalFrame.restoreButtonToolTip", "\uBCF5\uC6D0" },
            { "InternalFrameTitlePane.closeButton.textAndMnemonic", "\uB2EB\uAE30(&C)" },
            { "InternalFrameTitlePane.closeButtonAccessibleName", "\uB2EB\uAE30" },
            { "InternalFrameTitlePane.iconifyButtonAccessibleName", "\uC544\uC774\uCF58\uD654" },
            { "InternalFrameTitlePane.maximizeButton.textAndMnemonic", "\uCD5C\uB300\uD654(&X)" },
            { "InternalFrameTitlePane.maximizeButtonAccessibleName", "\uCD5C\uB300\uD654" },
            { "InternalFrameTitlePane.minimizeButton.textAndMnemonic", "\uCD5C\uC18C\uD654(&N)" },
            { "InternalFrameTitlePane.moveButton.textAndMnemonic", "\uC774\uB3D9(&M)" },
            { "InternalFrameTitlePane.restoreButton.textAndMnemonic", "\uBCF5\uC6D0(&R)" },
            { "InternalFrameTitlePane.sizeButton.textAndMnemonic", "\uD06C\uAE30(&S)" },
            { "IsindexView.prompt", "\uB2E4\uC74C\uC740 \uAC80\uC0C9 \uAC00\uB2A5\uD55C \uC778\uB371\uC2A4\uC785\uB2C8\uB2E4. \uAC80\uC0C9 \uD0A4\uC6CC\uB4DC \uC785\uB825:" },
            { "OptionPane.cancelButton.textAndMnemonic", "\uCDE8\uC18C" },
            { "OptionPane.inputDialog.titleAndMnemonic", "\uC785\uB825" },
            { "OptionPane.messageDialog.titleAndMnemonic", "\uBA54\uC2DC\uC9C0" },
            { "OptionPane.noButton.textAndMnemonic", "\uC544\uB2C8\uC624(&N)" },
            { "OptionPane.okButton.textAndMnemonic", "\uD655\uC778" },
            { "OptionPane.title.textAndMnemonic", "\uC635\uC158 \uC120\uD0DD" },
            { "OptionPane.yesButton.textAndMnemonic", "\uC608(&Y)" },
            { "PrintingDialog.abortButton.textAndMnemonic", "\uC911\uB2E8(&A)" },
            { "PrintingDialog.abortButtonToolTip.textAndMnemonic", "\uC778\uC1C4 \uC911\uB2E8" },
            { "PrintingDialog.contentAborting.textAndMnemonic", "\uC778\uC1C4 \uC911\uB2E8 \uC911..." },
            { "PrintingDialog.contentInitial.textAndMnemonic", "\uC778\uC1C4 \uC9C4\uD589 \uC911..." },
            { "PrintingDialog.contentProgress.textAndMnemonic", "\uC778\uC1C4\uB41C \uD398\uC774\uC9C0 {0}..." },
            { "PrintingDialog.titleAborting.textAndMnemonic", "\uC778\uC1C4(\uC911\uB2E8 \uC911)" },
            { "PrintingDialog.titleProgress.textAndMnemonic", "\uC778\uC1C4" },
            { "ProgressMonitor.progress.textAndMnemonic", "\uC9C4\uD589..." },
            { "SplitPane.leftButton.textAndMnemonic", "\uC67C\uCABD \uB2E8\uCD94" },
            { "SplitPane.rightButton.textAndMnemonic", "\uC624\uB978\uCABD \uB2E8\uCD94" },
        };
    }
}

==> icedtea-bin-src-7.2.5.6.tar.xz: com/sun/swing/internal/plaf/basic/resources/basic_ko.java <==
package com.sun.swing.internal.plaf.basic.resources;

import java.util.ListResourceBundle;

public final class basic_ko extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "AbstractButton.click.textAndMnemonic", "\uB204\uB974\uAE30" },
            { "AbstractDocument.addition.textAndMnemonic", "\uCD94\uAC00" },
            { "AbstractDocument.deletion.textAndMnemonic", "\uC0AD\uC81C" },
            { "AbstractDocument.redo.textAndMnemonic", "\uC7AC\uC2E4\uD589" },
            { "AbstractDocument.styleChange.textAndMnemonic", "\uC2A4\uD0C0\uC77C \uBCC0\uACBD" },
            { "AbstractDocument.undo.textAndMnemonic", "\uC2E4\uD589 \uCDE8\uC18C" },
            { "AbstractUndoableEdit.redo.textAndMnemonic", "\uC7AC\uC2E4\uD589" },
            { "AbstractUndoableEdit.undo.textAndMnemonic", "\uC2E4\uD589 \uCDE8\uC18C" },
            { "ColorChooser.cancel.textAndMnemonic", "\uCDE8\uC18C" },
            { "ColorChooser.cmyk.textAndMnemonic", "C&MYK" },
            { "ColorChooser.cmykAlpha.textAndMnemonic", "\uC54C\uD30C" },
            { "ColorChooser.cmykBlack.textAndMnemonic", "\uAC80\uC815\uC0C9" },
            { "ColorChooser.cmykCyan.textAndMnemonic", "\uCCAD\uB85D\uC0C9" },
            { "ColorChooser.cmykMagenta.textAndMnemonic", "\uC9C4\uD64D\uC0C9" },
            { "ColorChooser.cmykYellow.textAndMnemonic", "\uB178\uB780\uC0C9" },
            { "ColorChooser.hsl.textAndMnemonic", "HSL(&L)" },
            { "ColorChooser.hslHue.textAndMnemonic", "\uC0C9\uC870" },
            { "ColorChooser.hslLightness.textAndMnemonic", "\uBC1D\uAE30" },
            { "ColorChooser.hslSaturation.textAndMnemonic", "\uCC44\uB3C4" },
            { "ColorChooser.hslTransparency.textAndMnemonic", "\uD22C\uBA85" },
            { "ColorChooser.hsv.textAndMnemonic", "HSV(&H)" },
            { "ColorChooser.hsvHue.textAndMnemonic", "\uC0C9\uC870" },
            { "ColorChooser.hsvSaturation.textAndMnemonic", "\uCC44\uB3C4" },
            { "ColorChooser.hsvTransparency.textAndMnemonic", "\uD22C\uBA85" },
            { "ColorChooser.hsvValue.textAndMnemonic", "\uAC12" },
            { "ColorChooser.ok.textAndMnemonic", "\uD655\uC778" },
            { "ColorChooser.preview.textAndMnemonic", "\uBBF8\uB9AC\uBCF4\uAE30" },
            { "ColorChooser.reset.textAndMnemonic", "\uC7AC\uC124\uC815(&R)" },
            { "ColorChooser.rgb.textAndMnemonic", "RGB(&G)" },
            { "ColorChooser.rgbAlpha.textAndMnemonic", "\uC54C\uD30C" },
            { "ColorChooser.rgbBlue.textAndMnemonic", "\uD30C\uB780\uC0C9(&B)" },
            { "ColorChooser.rgbGreen.textAndMnemonic", "\uB179\uC0C9(&N)" },
            { "ColorChooser.rgbHexCode.textAndMnemonic", "\uC0C9\uC0C1 \uCF54\uB4DC(&C)" },
            { "ColorChooser.rgbRed.textAndMnemonic", "\uBE68\uAC04\uC0C9(&D)" },
            { "ColorChooser.sample.textAndMnemonic", "\uC0D8\uD50C \uD14D\uC2A4\uD2B8  \uC0D8\uD50C \uD14D\uC2A4\uD2B8" },
            { "ColorChooser.swatches.textAndMnemonic", "\uACAC\uBCF8(&S)" },
            { "ColorChooser.swatchesRecent.textAndMnemonic", "\uCD5C\uADFC \uBAA9\uB85D:" },
            { "ComboBox.togglePopup.textAndMnemonic", "togglePopup" },
            { "FileChooser.acceptAllFileFilter.textAndMnemonic", "\uBAA8\uB4E0 \uD30C\uC77C" },
            { "FileChooser.cancelButton.textAndMnemonic", "\uCDE8\uC18C" },
            { "FileChooser.cancelButtonToolTip.textAndMnemonic", "\uD30C\uC77C \uC120\uD0DD\uAE30 \uB300\uD654\uC0C1\uC790 \uC911\uB2E8" },
            { "FileChooser.directoryDescription.textAndMnemonic", "\uB514\uB809\uD1A0\uB9AC" },
            { "FileChooser.directoryOpenButton.textAndMnemonic", "\uC5F4\uAE30(&O)" },
            { "FileChooser.directoryOpenButtonToolTip.textAndMnemonic", "\uC120\uD0DD\uB41C \uB514\uB809\uD1A0\uB9AC \uC5F4\uAE30" },
            { "FileChooser.fileDescription.textAndMnemonic", "\uC77C\uBC18 \uD30C\uC77C" },
            { "FileChooser.fileSizeGigaBytes", "{0} GB" },
            { "FileChooser.fileSizeKiloBytes", "{0} KB" },
            { "FileChooser.fileSizeMegaBytes", "{0} MB" },
            { "FileChooser.filesDetailsAccessibleName", "\uD30C\uC77C \uC138\uBD80 \uC815\uBCF4" },
            { "FileChooser.filesListAccessibleName", "\uD30C\uC77C \uBAA9\uB85D" },
            { "FileChooser.helpButton.textAndMnemonic", "\uB3C4\uC6C0\uB9D0(&H)" },
            { "FileChooser.helpButtonToolTip.textAndMnemonic", "FileChooser \uB3C4\uC6C0\uB9D0" },
            { "FileChooser.newFolderError.textAndMnemonic", "\uC0C8 \uD3F4\uB354\uB97C \uC0DD\uC131\uD558\uB294 \uC911 \uC624\uB958\uAC00 \uBC1C\uC0DD\uD588\uC2B5\uB2C8\uB2E4." },
            { "FileChooser.newFolderErrorSeparator", ":" },
            { "FileChooser.newFolderParentDoesntExist.textAndMnemonic", "\uD3F4\uB354\uB97C \uC0DD\uC131\uD560 \uC218 \uC5C6\uC2B5\uB2C8\uB2E4.\n\n\uC2DC\uC2A4\uD15C\uC5D0\uC11C \uC9C0\uC815\uB41C \uACBD\uB85C\uB97C \uCC3E\uC744 \uC218 \uC5C6\uC2B5\uB2C8\uB2E4." },
            { "FileChooser.newFolderParentDoesntExistTitle.textAndMnemonic", "\uD3F4\uB354\uB97C \uC0DD\uC131\uD560 \uC218 \uC5C6\uC74C" },
            { "FileChooser.openButton.textAndMnemonic", "\uC5F4\uAE30(&O)" },
            { "FileChooser.openButtonToolTip.textAndMnemonic", "\uC120\uD0DD\uB41C \uD30C\uC77C \uC5F4\uAE30" },
            { "FileChooser.openDialogTitle.textAndMnemonic", "\uC5F4\uAE30" },
            { "FileChooser.other.newFolder", "NewFolder" },
            { "FileChooser.other.newFolder.subsequent", "NewFolder.{0}" },
            { "FileChooser.renameError.textAndMnemonic", "{0}\uC758 \uC774\uB984\uC744 \uBC14\uAFC0 \uC218 \uC5C6\uC2B5\uB2C8\uB2E4." },
            { "FileChooser.renameErrorFileExists.textAndMnemonic", "{0}\uC758 \uC774\uB984\uC744 \uBC14\uAFC0 \uC218 \uC5C6\uC74C: \uC9C0\uC815\uD55C \uC774\uB984\uC744 \uC0AC\uC6A9\uD558\uB294 \uD30C\uC77C\uC774 \uC874\uC7AC\uD569\uB2C8\uB2E4. \uB2E4\uB978 \uD30C\uC77C \uC774\uB984\uC744 \uC9C0\uC815\uD558\uC2ED\uC2DC\uC624." },
            { "FileChooser.renameErrorTitle.textAndMnemonic", "\uD30C\uC77C \uB610\uB294 \uD3F4\uB354 \uC774\uB984 \uBC14\uAFB8\uB294 \uC911 \uC624\uB958 \uBC1C\uC0DD" },
            { "FileChooser.saveButton.textAndMnemonic", "\uC800\uC7A5(&S)" },
            { "FileChooser.saveButtonToolTip.textAndMnemonic", "\uC120\uD0DD\uB41C \uD30C\uC77C \uC800\uC7A5" },
            { "FileChooser.saveDialogTitle.textAndMnemonic", "\uC800\uC7A5" },
            { "FileChooser.updateButton.textAndMnemonic", "\uC5C5\uB370\uC774\uD2B8(&U)" },
            { "FileChooser.updateButtonToolTip.textAndMnemonic", "\uB514\uB809\uD1A0\uB9AC \uBAA9\uB85D \uC5C5\uB370\uC774\uD2B8" },
            { "FileChooser.win32.newFolder", "\uC0C8 \uD3F4\uB354" },
            { "FileChooser.win32.newFolder.subsequent", "\uC0C8 \uD3F4\uB354({0})" },
            { "FormView.browseFileButton.textAndMnemonic", "\uCC3E\uC544\uBCF4\uAE30..." },
            { "FormView.resetButton.textAndMnemonic", "\uC7AC\uC124\uC815" },
            { "FormView.submitButton.textAndMnemonic", "\uC9C8\uC758 \uC81C\uCD9C" },
            { "InternalFrame.closeButtonToolTip", "\uB2EB\uAE30" },
            { "InternalFrame.iconButtonToolTip", "\uCD5C\uC18C\uD654" },
            { "InternalFrame.maxButtonToolTip", "\uCD5C\uB300\uD654" },
            { "InternalFrame.restoreButtonToolTip", "\uBCF5\uC6D0" },
            { "InternalFrameTitlePane.closeButton.textAndMnemonic", "\uB2EB\uAE30" },
            { "InternalFrameTitlePane.closeButtonAccessibleName", "\uB2EB\uAE30" },
            { "InternalFrameTitlePane.iconifyButtonAccessibleName", "\uC544\uC774\uCF58\uD654" },
            { "InternalFrameTitlePane.maximizeButton.textAndMnemonic", "\uCD5C\uB300\uD654" },
            { "InternalFrameTitlePane.maximizeButtonAccessibleName", "\uCD5C\uB300\uD654" },
            { "InternalFrameTitlePane.minimizeButton.textAndMnemonic", "\uCD5C\uC18C\uD654" },
            { "InternalFrameTitlePane.moveButton.textAndMnemonic", "\uC774\uB3D9" },
            { "InternalFrameTitlePane.restoreButton.textAndMnemonic", "\uBCF5\uC6D0" },
            { "InternalFrameTitlePane.sizeButton.textAndMnemonic", "\uD06C\uAE30" },
            { "IsindexView.prompt", "\uB2E4\uC74C\uC740 \uAC80\uC0C9 \uAC00\uB2A5\uD55C \uC778\uB371\uC2A4\uC785\uB2C8\uB2E4. \uAC80\uC0C9 \uD0A4\uC6CC\uB4DC \uC785\uB825:" },
            { "OptionPane.cancelButton.textAndMnemonic", "\uCDE8\uC18C" },
            { "OptionPane.inputDialog.titleAndMnemonic", "\uC785\uB825" },
            { "OptionPane.messageDialog.titleAndMnemonic", "\uBA54\uC2DC\uC9C0" },
            { "OptionPane.noButton.textAndMnemonic", "\uC544\uB2C8\uC624(&N)" },
            { "OptionPane.okButton.textAndMnemonic", "\uD655\uC778" },
            { "OptionPane.title.textAndMnemonic", "\uC635\uC158 \uC120\uD0DD" },
            { "OptionPane.yesButton.textAndMnemonic", "\uC608(&Y)" },
            { "PrintingDialog.abortButton.textAndMnemonic", "\uC911\uB2E8(&A)" },
            { "PrintingDialog.abortButtonToolTip.textAndMnemonic", "\uC778\uC1C4 \uC911\uB2E8" },
            { "PrintingDialog.contentAborting.textAndMnemonic", "\uC778\uC1C4 \uC911\uB2E8 \uC911..." },
            { "PrintingDialog.contentInitial.textAndMnemonic", "\uC778\uC1C4 \uC9C4\uD589 \uC911..." },
            { "PrintingDialog.contentProgress.textAndMnemonic", "\uC778\uC1C4\uB41C \uD398\uC774\uC9C0 {0}..." },
            { "PrintingDialog.titleAborting.textAndMnemonic", "\uC778\uC1C4(\uC911\uB2E8 \uC911)" },
            { "PrintingDialog.titleProgress.textAndMnemonic", "\uC778\uC1C4" },
            { "ProgressMonitor.progress.textAndMnemonic", "\uC9C4\uD589..." },
            { "SplitPane.leftButton.textAndMnemonic", "\uC67C\uCABD \uB2E8\uCD94" },
            { "SplitPane.rightButton.textAndMnemonic", "\uC624\uB978\uCABD \uB2E8\uCD94" },
        };
    }
}
